@@ -30,7 +30,7 @@ class Provider(DateTimeProvider):
     }
 
     def day_of_week(self) -> str:
-        day = self.date('%w')
+        day = self.date("%w")
         return self.DAY_NAMES[day]
 
     def month_name(self) -> str:
