@@ -2,6 +2,7 @@ import csv
 import hashlib
 import io
 import json
+import os
 import re
 import string
 import tarfile
@@ -16,25 +17,22 @@ from .. import BaseProvider
 
 localized = True
 
-csv.register_dialect('faker-csv', csv.excel, quoting=csv.QUOTE_ALL)
+csv.register_dialect("faker-csv", csv.excel, quoting=csv.QUOTE_ALL)
 
 
 class Provider(BaseProvider):
-
     def boolean(self, chance_of_getting_true: int = 50) -> bool:
         """Generate a random boolean value based on ``chance_of_getting_true``.
 
-        :sample size=10: chance_of_getting_true=25
-        :sample size=10: chance_of_getting_true=50
-        :sample size=10: chance_of_getting_true=75
+        :sample: chance_of_getting_true=25
+        :sample: chance_of_getting_true=50
+        :sample: chance_of_getting_true=75
         """
         return self.generator.random.randint(1, 100) <= chance_of_getting_true
 
     def null_boolean(self) -> Optional[bool]:
-        """Generate ``None``, ``True``, or ``False``, each with equal probability.
+        """Generate ``None``, ``True``, or ``False``, each with equal probability."""
 
-        :sample size=15:
-        """
         return {
             0: None,
             1: True,
@@ -44,10 +42,18 @@ class Provider(BaseProvider):
     def binary(self, length: int = (1 * 1024 * 1024)) -> bytes:
         """Generate a random binary blob of ``length`` bytes.
 
+        If this faker instance has been seeded, performance will be signficiantly reduced, to conform
+        to the seeding.
+
         :sample: length=64
         """
-        blob = [self.generator.random.randrange(256) for _ in range(length)]
-        return bytes(blob)
+        # If the generator has already been seeded, urandom can't be used
+        if self.generator._is_seeded:
+            blob = [self.generator.random.randrange(256) for _ in range(length)]
+            return bytes(blob)
+
+        # Generator is unseeded anyway, just use urandom
+        return os.urandom(length)
 
     def md5(self, raw_output: bool = False) -> Union[bytes, str]:
         """Generate a random MD5 hash.
@@ -91,9 +97,10 @@ class Provider(BaseProvider):
             return res.digest()
         return res.hexdigest()
 
-    def uuid4(self,
-              cast_to: Optional[Union[Callable[[uuid.UUID], str], Callable[[uuid.UUID], bytes]]] = str,
-              ) -> Union[bytes, str, uuid.UUID]:
+    def uuid4(
+        self,
+        cast_to: Optional[Union[Callable[[uuid.UUID], str], Callable[[uuid.UUID], bytes]]] = str,
+    ) -> Union[bytes, str, uuid.UUID]:
         """Generate a random UUID4 object and cast it to another type if specified using a callable ``cast_to``.
 
         By default, ``cast_to`` is set to ``str``.
@@ -109,12 +116,14 @@ class Provider(BaseProvider):
             return cast_to(generated_uuid)
         return generated_uuid
 
-    def password(self,
-                 length: int = 10,
-                 special_chars: bool = True,
-                 digits: bool = True,
-                 upper_case: bool = True,
-                 lower_case: bool = True) -> str:
+    def password(
+        self,
+        length: int = 10,
+        special_chars: bool = True,
+        digits: bool = True,
+        upper_case: bool = True,
+        lower_case: bool = True,
+    ) -> str:
         """Generate a random password of the specified ``length``.
 
         The arguments ``special_chars``, ``digits``, ``upper_case``, and ``lower_case`` control
@@ -130,23 +139,19 @@ class Provider(BaseProvider):
         choices = ""
         required_tokens = []
         if special_chars:
-            required_tokens.append(
-                self.generator.random.choice("!@#$%^&*()_+"))
+            required_tokens.append(self.generator.random.choice("!@#$%^&*()_+"))
             choices += "!@#$%^&*()_+"
         if digits:
             required_tokens.append(self.generator.random.choice(string.digits))
             choices += string.digits
         if upper_case:
-            required_tokens.append(
-                self.generator.random.choice(string.ascii_uppercase))
+            required_tokens.append(self.generator.random.choice(string.ascii_uppercase))
             choices += string.ascii_uppercase
         if lower_case:
-            required_tokens.append(
-                self.generator.random.choice(string.ascii_lowercase))
+            required_tokens.append(self.generator.random.choice(string.ascii_lowercase))
             choices += string.ascii_lowercase
 
-        assert len(
-            required_tokens) <= length, "Required length is shorter than required characters"
+        assert len(required_tokens) <= length, "Required length is shorter than required characters"
 
         # Generate a first version of the password
         chars: str = self.random_choices(choices, length=length)  # type: ignore
@@ -154,20 +159,21 @@ class Provider(BaseProvider):
         # Pick some unique locations
         random_indexes: Set[int] = set()
         while len(random_indexes) < len(required_tokens):
-            random_indexes.add(
-                self.generator.random.randint(0, len(chars) - 1))
+            random_indexes.add(self.generator.random.randint(0, len(chars) - 1))
 
         # Replace them with the required characters
         for i, index in enumerate(random_indexes):
             chars[index] = required_tokens[i]  # type: ignore
 
-        return ''.join(chars)
+        return "".join(chars)
 
-    def zip(self,
-            uncompressed_size: int = 65536,
-            num_files: int = 1,
-            min_file_size: int = 4096,
-            compression: Optional[str] = None) -> bytes:
+    def zip(
+        self,
+        uncompressed_size: int = 65536,
+        num_files: int = 1,
+        min_file_size: int = 4096,
+        compression: Optional[str] = None,
+    ) -> bytes:
         """Generate a bytes object containing a random valid zip archive file.
 
         The number and sizes of files contained inside the resulting archive can be controlled
@@ -187,30 +193,32 @@ class Provider(BaseProvider):
         :sample: uncompressed_size=256, num_files=4, min_file_size=32
         :sample: uncompressed_size=256, num_files=32, min_file_size=4, compression='bz2'
         """
-        if any([
-            not isinstance(num_files, int) or num_files <= 0,
-            not isinstance(min_file_size, int) or min_file_size <= 0,
-            not isinstance(uncompressed_size, int) or uncompressed_size <= 0,
-        ]):
+        if any(
+            [
+                not isinstance(num_files, int) or num_files <= 0,
+                not isinstance(min_file_size, int) or min_file_size <= 0,
+                not isinstance(uncompressed_size, int) or uncompressed_size <= 0,
+            ]
+        ):
             raise ValueError(
-                '`num_files`, `min_file_size`, and `uncompressed_size` must be positive integers',
+                "`num_files`, `min_file_size`, and `uncompressed_size` must be positive integers",
             )
         if min_file_size * num_files > uncompressed_size:
             raise AssertionError(
-                '`uncompressed_size` is smaller than the calculated minimum required size',
+                "`uncompressed_size` is smaller than the calculated minimum required size",
             )
-        if compression in ['bzip2', 'bz2']:
+        if compression in ["bzip2", "bz2"]:
             compression_ = zipfile.ZIP_BZIP2
-        elif compression in ['lzma', 'xz']:
+        elif compression in ["lzma", "xz"]:
             compression_ = zipfile.ZIP_LZMA
-        elif compression in ['deflate', 'gzip', 'gz']:
+        elif compression in ["deflate", "gzip", "gz"]:
             compression_ = zipfile.ZIP_DEFLATED
         else:
             compression_ = zipfile.ZIP_STORED
 
         zip_buffer = io.BytesIO()
         remaining_size = uncompressed_size
-        with zipfile.ZipFile(zip_buffer, mode='w', compression=compression_) as zip_handle:
+        with zipfile.ZipFile(zip_buffer, mode="w", compression=compression_) as zip_handle:
             for file_number in range(1, num_files + 1):
                 filename = self.generator.pystr() + str(file_number)
 
@@ -225,11 +233,13 @@ class Provider(BaseProvider):
                 zip_handle.writestr(filename, data)
         return zip_buffer.getvalue()
 
-    def tar(self,
-            uncompressed_size: int = 65536,
-            num_files: int = 1,
-            min_file_size: int = 4096,
-            compression: Optional[str] = None) -> bytes:
+    def tar(
+        self,
+        uncompressed_size: int = 65536,
+        num_files: int = 1,
+        min_file_size: int = 4096,
+        compression: Optional[str] = None,
+    ) -> bytes:
         """Generate a bytes object containing a random valid tar file.
 
         The number and sizes of files contained inside the resulting archive can be controlled
@@ -249,26 +259,28 @@ class Provider(BaseProvider):
         :sample: uncompressed_size=256, num_files=4, min_file_size=32
         :sample: uncompressed_size=256, num_files=32, min_file_size=4, compression='bz2'
         """
-        if any([
-            not isinstance(num_files, int) or num_files <= 0,
-            not isinstance(min_file_size, int) or min_file_size <= 0,
-            not isinstance(uncompressed_size, int) or uncompressed_size <= 0,
-        ]):
+        if any(
+            [
+                not isinstance(num_files, int) or num_files <= 0,
+                not isinstance(min_file_size, int) or min_file_size <= 0,
+                not isinstance(uncompressed_size, int) or uncompressed_size <= 0,
+            ]
+        ):
             raise ValueError(
-                '`num_files`, `min_file_size`, and `uncompressed_size` must be positive integers',
+                "`num_files`, `min_file_size`, and `uncompressed_size` must be positive integers",
             )
         if min_file_size * num_files > uncompressed_size:
             raise AssertionError(
-                '`uncompressed_size` is smaller than the calculated minimum required size',
+                "`uncompressed_size` is smaller than the calculated minimum required size",
             )
-        if compression in ['gzip', 'gz']:
-            mode = 'w:gz'
-        elif compression in ['bzip2', 'bz2']:
-            mode = 'w:bz2'
-        elif compression in ['lzma', 'xz']:
-            mode = 'w:xz'
+        if compression in ["gzip", "gz"]:
+            mode = "w:gz"
+        elif compression in ["bzip2", "bz2"]:
+            mode = "w:bz2"
+        elif compression in ["lzma", "xz"]:
+            mode = "w:xz"
         else:
-            mode = 'w'
+            mode = "w"
 
         tar_buffer = io.BytesIO()
         remaining_size = uncompressed_size
@@ -293,11 +305,13 @@ class Provider(BaseProvider):
                 file_buffer.close()
         return tar_buffer.getvalue()
 
-    def image(self,
-              size: Tuple[int, int] = (256, 256),
-              image_format: str = 'png',
-              hue: Optional[Union[int, Sequence[int], str]] = None,
-              luminosity: Optional[str] = None) -> bytes:
+    def image(
+        self,
+        size: Tuple[int, int] = (256, 256),
+        image_format: str = "png",
+        hue: Optional[Union[int, Sequence[int], str]] = None,
+        luminosity: Optional[str] = None,
+    ) -> bytes:
         """Generate an image and draw a random polygon on it using the Python Image Library.
         Without it installed, this provider won't be functional. Returns the bytes representing
         the image in a given format.
@@ -312,8 +326,8 @@ class Provider(BaseProvider):
         The arguments ``hue`` and ``luminosity`` are the same as in the color provider and are simply forwarded to
         it to generate both the background and the shape colors. Therefore, you can ask for a "dark blue" image, etc.
 
-        :sample size=2: size=(2, 2), hue='purple', luminosity='bright', image_format='pdf'
-        :sample size=2: size=(16, 16), hue=[90,270], image_format='ico'
+        :sample: size=(2, 2), hue='purple', luminosity='bright', image_format='pdf'
+        :sample: size=(16, 16), hue=[90,270], image_format='ico'
         """
         try:
             import PIL.Image
@@ -322,13 +336,10 @@ class Provider(BaseProvider):
             raise UnsupportedFeature("`image` requires the `Pillow` python library.", "image")
 
         (width, height) = size
-        image = PIL.Image.new('RGB', size, self.generator.color(hue=hue, luminosity=luminosity))
+        image = PIL.Image.new("RGB", size, self.generator.color(hue=hue, luminosity=luminosity))
         draw = PIL.ImageDraw.Draw(image)
         draw.polygon(
-            [
-                (self.random_int(0, width), self.random_int(0, height))
-                for _ in range(self.random_int(3, 12))
-            ],
+            [(self.random_int(0, width), self.random_int(0, height)) for _ in range(self.random_int(3, 12))],
             fill=self.generator.color(hue=hue, luminosity=luminosity),
             outline=self.generator.color(hue=hue, luminosity=luminosity),
         )
@@ -337,13 +348,15 @@ class Provider(BaseProvider):
             fobj.seek(0)
             return fobj.read()
 
-    def dsv(self,
-            dialect: str = 'faker-csv',
-            header: Optional[Sequence[str]] = None,
-            data_columns: Tuple[str, str] = ('{{name}}', '{{address}}'),
-            num_rows: int = 10,
-            include_row_ids: bool = False,
-            **fmtparams: Any) -> str:
+    def dsv(
+        self,
+        dialect: str = "faker-csv",
+        header: Optional[Sequence[str]] = None,
+        data_columns: Tuple[str, str] = ("{{name}}", "{{address}}"),
+        num_rows: int = 10,
+        include_row_ids: bool = False,
+        **fmtparams: Any,
+    ) -> str:
         """Generate random delimiter-separated values.
 
         This method's behavior share some similarities with ``csv.writer``. The ``dialect`` and
@@ -373,14 +386,14 @@ class Provider(BaseProvider):
         """
 
         if not isinstance(num_rows, int) or num_rows <= 0:
-            raise ValueError('`num_rows` must be a positive integer')
+            raise ValueError("`num_rows` must be a positive integer")
         if not isinstance(data_columns, (list, tuple)):
-            raise TypeError('`data_columns` must be a tuple or a list')
+            raise TypeError("`data_columns` must be a tuple or a list")
         if header is not None:
             if not isinstance(header, (list, tuple)):
-                raise TypeError('`header` must be a tuple or a list')
+                raise TypeError("`header` must be a tuple or a list")
             if len(header) != len(data_columns):
-                raise ValueError('`header` and `data_columns` must have matching lengths')
+                raise ValueError("`header` and `data_columns` must have matching lengths")
 
         dsv_buffer = io.StringIO()
         writer = csv.writer(dsv_buffer, dialect=dialect, **fmtparams)
@@ -388,7 +401,7 @@ class Provider(BaseProvider):
         if header:
             if include_row_ids:
                 header = list(header)
-                header.insert(0, 'ID')
+                header.insert(0, "ID")
             writer.writerow(header)
 
         for row_num in range(1, num_rows + 1):
@@ -400,11 +413,13 @@ class Provider(BaseProvider):
 
         return dsv_buffer.getvalue()
 
-    def csv(self,
-            header: Optional[Sequence[str]] = None,
-            data_columns: Tuple[str, str] = ('{{name}}', '{{address}}'),
-            num_rows: int = 10,
-            include_row_ids: bool = False) -> str:
+    def csv(
+        self,
+        header: Optional[Sequence[str]] = None,
+        data_columns: Tuple[str, str] = ("{{name}}", "{{address}}"),
+        num_rows: int = 10,
+        include_row_ids: bool = False,
+    ) -> str:
         """Generate random comma-separated values.
 
         For more information on the different arguments of this method, please refer to
@@ -416,15 +431,20 @@ class Provider(BaseProvider):
                 num_rows=10, include_row_ids=True
         """
         return self.dsv(
-            header=header, data_columns=data_columns, num_rows=num_rows,
-            include_row_ids=include_row_ids, delimiter=',',
+            header=header,
+            data_columns=data_columns,
+            num_rows=num_rows,
+            include_row_ids=include_row_ids,
+            delimiter=",",
         )
 
-    def tsv(self,
-            header: Optional[Sequence[str]] = None,
-            data_columns: Tuple[str, str] = ('{{name}}', '{{address}}'),
-            num_rows: int = 10,
-            include_row_ids: bool = False) -> str:
+    def tsv(
+        self,
+        header: Optional[Sequence[str]] = None,
+        data_columns: Tuple[str, str] = ("{{name}}", "{{address}}"),
+        num_rows: int = 10,
+        include_row_ids: bool = False,
+    ) -> str:
         """Generate random tab-separated values.
 
         For more information on the different arguments of this method, please refer to
@@ -436,15 +456,20 @@ class Provider(BaseProvider):
                 num_rows=10, include_row_ids=True
         """
         return self.dsv(
-            header=header, data_columns=data_columns, num_rows=num_rows,
-            include_row_ids=include_row_ids, delimiter='\t',
+            header=header,
+            data_columns=data_columns,
+            num_rows=num_rows,
+            include_row_ids=include_row_ids,
+            delimiter="\t",
         )
 
-    def psv(self,
-            header: Optional[Sequence[str]] = None,
-            data_columns: Tuple[str, str] = ('{{name}}', '{{address}}'),
-            num_rows: int = 10,
-            include_row_ids: bool = False) -> str:
+    def psv(
+        self,
+        header: Optional[Sequence[str]] = None,
+        data_columns: Tuple[str, str] = ("{{name}}", "{{address}}"),
+        num_rows: int = 10,
+        include_row_ids: bool = False,
+    ) -> str:
         """Generate random pipe-separated values.
 
         For more information on the different arguments of this method, please refer to
@@ -456,14 +481,14 @@ class Provider(BaseProvider):
                 num_rows=10, include_row_ids=True
         """
         return self.dsv(
-            header=header, data_columns=data_columns, num_rows=num_rows,
-            include_row_ids=include_row_ids, delimiter='|',
+            header=header,
+            data_columns=data_columns,
+            num_rows=num_rows,
+            include_row_ids=include_row_ids,
+            delimiter="|",
         )
 
-    def json(self,
-             data_columns: List = None,
-             num_rows: int = 10,
-             indent: int = None) -> str:
+    def json(self, data_columns: Optional[List] = None, num_rows: int = 10, indent: Optional[int] = None) -> str:
         """
         Generate random JSON structure values.
 
@@ -507,8 +532,8 @@ class Provider(BaseProvider):
                 {'min_value': 50, 'max_value': 100})], num_rows=1
         """
         default_data_columns = {
-            'name': '{{name}}',
-            'residency': '{{address}}',
+            "name": "{{name}}",
+            "residency": "{{address}}",
         }
         data_columns: Union[List, Dict] = data_columns if data_columns else default_data_columns
 
@@ -519,7 +544,7 @@ class Provider(BaseProvider):
                 kwargs = arguments[0] if arguments else {}
 
                 if not isinstance(kwargs, dict):
-                    raise TypeError('Invalid arguments type. Must be a dictionary')
+                    raise TypeError("Invalid arguments type. Must be a dictionary")
 
                 if name is None:
                     return self._value_format_selection(definition, **kwargs)
@@ -527,8 +552,7 @@ class Provider(BaseProvider):
                 if isinstance(definition, tuple):
                     entry[name] = process_list_structure(definition)
                 elif isinstance(definition, (list, set)):
-                    entry[name] = [process_list_structure([item])
-                                   for item in definition]
+                    entry[name] = [process_list_structure([item]) for item in definition]
                 else:
                     entry[name] = self._value_format_selection(definition, **kwargs)
             return entry
@@ -542,8 +566,7 @@ class Provider(BaseProvider):
             if isinstance(data, dict):
                 for name, definition in data.items():
                     if isinstance(definition, (tuple, list, set)):
-                        entry[name] = [process_dict_structure(item)
-                                       for item in definition]
+                        entry[name] = [process_dict_structure(item) for item in definition]
                     elif isinstance(definition, (dict, int, float, bool)):
                         entry[name] = process_dict_structure(definition)
                     else:
@@ -559,7 +582,7 @@ class Provider(BaseProvider):
             if isinstance(data_columns, list):
                 return process_list_structure(data_columns)
 
-            raise TypeError('Invalid data_columns type. Must be a dictionary or list')
+            raise TypeError("Invalid data_columns type. Must be a dictionary or list")
 
         if num_rows == 1:
             return json.dumps(create_json_structure(data_columns), indent=indent)
@@ -567,10 +590,7 @@ class Provider(BaseProvider):
         data = [create_json_structure(data_columns) for _ in range(num_rows)]
         return json.dumps(data, indent=indent)
 
-    def fixed_width(self,
-                    data_columns: list = None,
-                    num_rows: int = 10,
-                    align: str = 'left') -> str:
+    def fixed_width(self, data_columns: Optional[list] = None, num_rows: int = 10, align: str = "left") -> str:
         """
         Generate random fixed width values.
 
@@ -607,14 +627,14 @@ class Provider(BaseProvider):
                 'max_value': 100})], align='right', num_rows=2
         """
         default_data_columns = [
-            (20, 'name'),
-            (3, 'pyint', {'max_value': 20}),
+            (20, "name"),
+            (3, "pyint", {"max_value": 20}),
         ]
         data_columns = data_columns if data_columns else default_data_columns
         align_map = {
-            'left': '<',
-            'middle': '^',
-            'right': '>',
+            "left": "<",
+            "middle": "^",
+            "right": ">",
         }
         data = []
 
@@ -625,13 +645,13 @@ class Provider(BaseProvider):
                 kwargs = arguments[0] if arguments else {}
 
                 if not isinstance(kwargs, dict):
-                    raise TypeError('Invalid arguments type. Must be a dictionary')
+                    raise TypeError("Invalid arguments type. Must be a dictionary")
 
                 result = self._value_format_selection(definition, **kwargs)
                 row.append(f'{result:{align_map.get(align, "<")}{width}}'[:width])
 
-            data.append(''.join(row))
-        return '\n'.join(data)
+            data.append("".join(row))
+        return "\n".join(data)
 
     def _value_format_selection(self, definition: str, **kwargs: Any) -> Union[int, str]:
         """
@@ -646,16 +666,16 @@ class Provider(BaseProvider):
         """
 
         # Check for PyStr first as complex strings may start with @
-        if re.match(r'.*\{\{.*\}\}.*', definition):
+        if re.match(r".*\{\{.*\}\}.*", definition):
             return self.generator.pystr_format(definition)
 
         # Check for fixed @words that won't be generated
-        if re.match(r'^@.*', definition):
-            return definition.lstrip('@')
+        if re.match(r"^@.*", definition):
+            return definition.lstrip("@")
 
         # Check if a argument group has been supplied
-        if re.match(r'^[a-zA-Z0-9_-]*:\w', definition):
-            definition, argument_group = definition.split(':')
+        if re.match(r"^[a-zA-Z0-9_-]*:\w", definition):
+            definition, argument_group = definition.split(":")
             arguments = self.generator.get_arguments(argument_group.strip())
 
             return self.generator.format(definition.strip(), **arguments)
